Parametric package
=======================

This package provides an interface for parametric models.

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   adam.parametric.casadi
   adam.parametric.jax
   adam.parametric.model
   adam.parametric.numpy
   adam.parametric.pytorch

Module contents
---------------

.. automodule:: adam.parametric
   :members:
   :undoc-members:
   :show-inheritance:
